## Sampling

Settings that change how the initial binary population is sampled

### `sampling_method`

Select which models to use to generate an initial sample of binary parameters at Zero Age Main Sequence

Default: independent

Option details

- `independent`: Initialize binaries with independent parameter distributions for the primary mass, mass ratio, eccentricity, separation, and binary fraction
- `multidim`: Initialize binaries with multidimensional parameter distributions according to Moe & Di Stefano 2017

### `primary_model`

Model for sampling primary masses
[Only used when `sampling_method = independent`]

Default: kroupa01

Option details

- `salpeter55`: Use the Salpeter 1955 IMF
- `kroupa93`: Use the Kroupa 1993 IMF
- `kroupa01`: Use the Kroupa 2001 IMF

### `porb_model`

Model for sampling orbital periods
[Only used when `sampling_method = independent`]

Default: sana12

Option details

- `sana12`: Sample from power law orbital period between 0.15 < log(P/day) < 5.5 following Sana+2012
- `log_uniform`: Sample semi-major axis flat in log space from RRLO < 0.5 up to \(10^{5} {\rm R_{\odot}}\) according to Abt (1983) and consistent with Dominik+2012,2013 - then convert to orbital period in days using Kepler's third law.
- `renzo19`: Uses `sana12` for massive binaries (\(m_1 > 15 {\rm M_{\odot}}\)) and flat in log otherwise (following Renzo+19).
- `raghavan10`: Sample log normal orbital periods in days with mean_logP = 4.9 and sigma_logP = 2.3 between \(0 < \log_{10}(P / {\rm day}) < 9\) following Raghavan+2010
- `moe19`: As `raghavan10` but with different close binary fractions following Moe+2019
- `custom`: Sample from a custom power law. The user provides a dictionary of min, max and slope values for the power law.

### `ecc_model`

Model for sampling eccentricity
[Only used when `sampling_method = independent`]

Default: sana12

Option details

- `thermal`: Samples from a thermal eccentricity distribution following Heggie (1975)
- `uniform`: Samples from a uniform eccentricity distribution
- `sana12`: Samples from the eccentricity distribution from Sana+2012
- `circular`: Assumes zero eccentricity for all systems

### `qmin`

Minimum mass ratio for sampling the secondary mass
[Only used when `sampling_method = independent`]

Default: -1

Option details

The assumed mass ratio distribution is flat in \(q \equiv m_2 / m_1\). NOTE: only one of `qmin` and `m2_min` should be specified.

- `values in [0, 1]`: Sets the minimum mass ratio
- `-1`: Set the minimum mass ratio such that the pre-MS lifetime of the secondary is not longer than the full lifetime of the primary if it were to evolve as a single star

### `m2_min`

Minimum secondary mass for sampling
[Only used when `sampling_method = independent`]

Default: 0.1

Option details

NOTE: only one of `qmin` and `m2_min` should be specified.

- `positive values`: Sample the secondary mass uniformly between `m2_min` and `mass_1`
- `0.1`: Default value

### `binfrac_model`

Model for sampling binary fraction
[Only used when `sampling_method = independent`]

Default: 0.5

Option details

- `values between [0, 1]`: Fixed binary fraction
- `vanHaaften`: Primary mass dependent binary fraction following van Haaften+05
- `offner22`: Primary mass dependent binary fraction following Offner+22
- `0.5`: Default value

### `SF_start`

Sets the time in the past when star formation initiates in Myr.

Default: 13700.0

Option details

- `positive values`: Start time of star formation in Myr
- `13700.0`: For example, this specifies a start time at the beginning of a Hubble time

### `SF_duration`

Sets the duration of constant star formation from ``SF_start`` in Myr.

Default: 0.0

Option details

- `positive values`: Duration of star formation in Myr
- `0.0`: A single burst of star formation
- `13700.0`: For example, this specifies a constant star formation rate over a Hubble time

### `metallicity`

Sets the metallicity of the stellar population.

Default: 0.02

Option details

COSMIC expects an absolute metallicity (i.e., NOT units of zsun)

- `positive values`: Absolute metallicity
- `0.02`: For example, this sets the metallicity to approximately solar metallicity